Changelog
=========

0.1.4 released 2018-10-09
-------------------------

- prep for pyp (9768bdb_)
- replace function from missing wheel.install (2699de5_)
- fix bug with handling multiple reqs files (dc3eb9a_)
- better default logging (48c49c7_)

.. _9768bdb: https://github.com/level12/wheelhouse/commit/9768bdb
.. _2699de5: https://github.com/level12/wheelhouse/commit/2699de5
.. _dc3eb9a: https://github.com/level12/wheelhouse/commit/dc3eb9a
.. _48c49c7: https://github.com/level12/wheelhouse/commit/48c49c7



0.1.3 - 2017-05-30
------------------

* BUG: fix bug in handling multiple requirements files
